@@ -23,6 +23,7 @@ from unittest.mock import patch
 from io import StringIO
 
 import defusedxml.lxml as secET
+from gvm.errors import InvalidArgumentType
 from gvm.xml import pretty_print
 
 
@@ -85,7 +86,7 @@ class PrettyPrintTestCase(unittest.TestCase):
 
     def test_pretty_print_with_string(self):
         xml_str = '<test><this><with id="a">and text</with></this></test>'
-        # elem = secET.fromstring(xml_str)
+
         expected_xml_string = (
             '<test>\n'
             '  <this>\n'
@@ -101,6 +102,23 @@ class PrettyPrintTestCase(unittest.TestCase):
 
         self.assertEqual(xml_string, expected_xml_string)
 
+    @patch('sys.stdout', new_callable=StringIO)
+    def test_pretty_print_with_string_to_stdout(self, mock_stdout):
+        xml_str = '<test><this><with id="a">and text</with></this></test>'
+
+        expected_xml_string = (
+            '<test>\n'
+            '  <this>\n'
+            '    <with id="a">and text</with>\n'
+            '  </this>\n'
+            '</test>\n'
+        )
+
+        pretty_print(xml_str, sys.stdout)
+        xml_string = mock_stdout.getvalue()
+
+        self.assertEqual(xml_string, expected_xml_string)
+
     def test_pretty_print_with_dict(self):
         xml_str = '<test><this><with id="a">and text</with></this></test>'
         elem = secET.fromstring(xml_str)
@@ -144,6 +162,13 @@ class PrettyPrintTestCase(unittest.TestCase):
 
         self.assertEqual(xml_string, expected_xml_string)
 
+    def test_pretty_print_no_xml(self):
+        number = 1
+        stringio = StringIO()
+
+        with self.assertRaises(InvalidArgumentType):
+            pretty_print(number, file=stringio)
+
     def test_pretty_print_type_error(self):
         xml_str = '<test><this><with id="a">and text</with></this></test>'
         elem = secET.fromstring(xml_str)
